PCB Environment: dsn::PCB Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
dsn::PCB Struct Reference

## Public Member Functions
std::string | str () const

## Data Fields
std::string | name
int | unit_ex
int | resolution_ex
double | unit {1.0}
double | resolution

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Loaders/DSN.hpp